"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, definition: Dict, compatible_namespace_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a system. The system is validated against the entities in the latest version of the user's namespace unless another namespace version is specified in the request.

    Args:
        definition(Dict): The DefinitionDocument used to create the system.
        compatible_namespace_version(int, optional): The namespace version in which the system is to be created. If no value is specified, the latest version is used by default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.template.init.create(
                ctx, definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.template.init.create definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="create_system_template",
        op_kwargs={
            "definition": definition,
            "compatibleNamespaceVersion": compatible_namespace_version,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a system. New deployments can't contain the system after its deletion. Existing deployments that contain the system will continue to work because they use a snapshot of the system that is taken when it is deployed.

    Args:
        id_(str): The ID of the system to be deleted. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.template.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.template.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="delete_system_template",
        op_kwargs={"id": id_},
    )


async def deprecate(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deprecates the specified system.

    Args:
        id_(str): The ID of the system to delete. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.template.init.deprecate(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.template.init.deprecate id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="deprecate_system_template",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str, revision_number: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a system.

    Args:
        id_(str): The ID of the system to get. This ID must be in the user's namespace. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME .
        revision_number(int, optional): The number that specifies the revision of the system to get. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.template.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.template.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="get_system_template",
        op_kwargs={"id": id_, "revisionNumber": revision_number},
    )


async def search(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for summary information about systems in the user's account. You can filter by the ID of a workflow to return only systems that use the specified workflow.

    Args:
        filters(List, optional): An array of filters that limit the result set. The only valid filter is FLOW_TEMPLATE_ID. Defaults to None.
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.template.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.template.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="search_system_templates",
        op_kwargs={
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub, ctx, id_: str, definition: Dict, compatible_namespace_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified system. You don't need to run this action after updating a workflow. Any deployment that uses the system will see the changes in the system when it is redeployed.

    Args:
        id_(str): The ID of the system to be updated. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME .
        definition(Dict): The DefinitionDocument that contains the updated system definition.
        compatible_namespace_version(int, optional): The version of the user's namespace. Defaults to the latest version of the user's namespace. If no value is specified, the latest version is used by default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.template.init.update(
                ctx, id_=value, definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.template.init.update id_=value, definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="update_system_template",
        op_kwargs={
            "id": id_,
            "definition": definition,
            "compatibleNamespaceVersion": compatible_namespace_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new search domain. For more information, see Creating a Search Domain in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A name for the domain you are creating. Allowed characters are a-z (lower-case letters), 0-9, and hyphen (-). Domain names must start with a letter or number and be at least 3 and no more than 28 characters long.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.domain.init.create(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.domain.init.create domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="create_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def delete(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently deletes a search domain and all of its data. Once a domain has been deleted, it cannot be recovered. For more information, see Deleting a Search Domain in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): The name of the domain you want to permanently delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.domain.init.delete(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.domain.init.delete domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="delete_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def describe_all(hub, ctx, domain_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the search domains owned by this account. Can be limited to specific domains. Shows all domains by default. To get the number of searchable documents in a domain, use the console or submit a matchall request to your domain's search endpoint: q=matchall&amp;q.parser=structured&amp;size=0. For more information, see Getting Information about a Search Domain in the Amazon CloudSearch Developer Guide.

    Args:
        domain_names(List, optional): The names of the domains you want to include in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.domain.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.domain.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_domains",
        op_kwargs={"DomainNames": domain_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subdirectory: str,
    server_hostname: str,
    user: str,
    password: str,
    agent_arns: List,
    domain: str = None,
    mount_options: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Defines a file system on a Server Message Block (SMB) server that can be read from or written to.

    Args:
        subdirectory(str): The subdirectory in the SMB file system that is used to read data from the SMB source location or write data to the SMB destination. The SMB path should be a path that's exported by the SMB server, or a subdirectory of that path. The path should be such that it can be mounted by other SMB clients in your network.   Subdirectory must be specified with forward slashes. For example, /path/to/folder.  To transfer all the data in the folder you specified, DataSync needs to have permissions to mount the SMB share, as well as to access all the data in that share. To ensure this, either ensure that the user/password specified belongs to the user who can mount the share, and who has the appropriate permissions for all of the files and directories that you want DataSync to access, or use credentials of a member of the Backup Operators group to mount the share. Doing either enables the agent to access the data. For the agent to access directories, you must additionally enable all execute access.
        server_hostname(str): The name of the SMB server. This value is the IP address or Domain Name Service (DNS) name of the SMB server. An agent that is installed on-premises uses this hostname to mount the SMB server in a network.  This name must either be DNS-compliant or must be an IP version 4 (IPv4) address. .
        user(str): The user who can mount the share, has the permissions to access files and folders in the SMB share. For information about choosing a user name that ensures sufficient permissions to files, folders, and metadata, see user.
        domain(str, optional): The name of the Windows domain that the SMB server belongs to. Defaults to None.
        password(str): The password of the user who can mount the share, has the permissions to access files and folders in the SMB share.
        agent_arns(List): The Amazon Resource Names (ARNs) of agents to use for a Simple Message Block (SMB) location. .
        mount_options(Dict, optional): The mount options used by DataSync to access the SMB server. Defaults to None.
        tags(List, optional): The key-value pair that represents the tag that you want to add to the location. The value can be an empty string. We recommend using tags to name your resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.smb.create(
                ctx,
                subdirectory=value,
                server_hostname=value,
                user=value,
                password=value,
                agent_arns=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.smb.create subdirectory=value, server_hostname=value, user=value, password=value, agent_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_location_smb",
        op_kwargs={
            "Subdirectory": subdirectory,
            "ServerHostname": server_hostname,
            "User": user,
            "Domain": domain,
            "Password": password,
            "AgentArns": agent_arns,
            "MountOptions": mount_options,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, location_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata, such as the path and user information about an SMB location.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the SMB location to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.smb.describe(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.smb.describe location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_location_smb",
        op_kwargs={"LocationArn": location_arn},
    )


async def update(
    hub,
    ctx,
    location_arn: str,
    subdirectory: str = None,
    user: str = None,
    domain: str = None,
    password: str = None,
    agent_arns: List = None,
    mount_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates some of the parameters of a previously created location for Server Message Block (SMB) file system access. For information about creating an SMB location, see Creating a location for SMB.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the SMB location to update.
        subdirectory(str, optional): The subdirectory in the SMB file system that is used to read data from the SMB source location or write data to the SMB destination. The SMB path should be a path that's exported by the SMB server, or a subdirectory of that path. The path should be such that it can be mounted by other SMB clients in your network.   Subdirectory must be specified with forward slashes. For example, /path/to/folder.  To transfer all the data in the folder that you specified, DataSync must have permissions to mount the SMB share and to access all the data in that share. To ensure this, do either of the following:   Ensure that the user/password specified belongs to the user who can mount the share and who has the appropriate permissions for all of the files and directories that you want DataSync to access.   Use credentials of a member of the Backup Operators group to mount the share.    Doing either of these options enables the agent to access the data. For the agent to access directories, you must also enable all execute access. Defaults to None.
        user(str, optional): The user who can mount the share has the permissions to access files and folders in the SMB share. Defaults to None.
        domain(str, optional): The name of the Windows domain that the SMB server belongs to. Defaults to None.
        password(str, optional): The password of the user who can mount the share has the permissions to access files and folders in the SMB share. Defaults to None.
        agent_arns(List, optional): The Amazon Resource Names (ARNs) of agents to use for a Simple Message Block (SMB) location. Defaults to None.
        mount_options(Dict, optional): Represents the mount options that are available for DataSync to access an SMB location. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.smb.update(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.smb.update location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="update_location_smb",
        op_kwargs={
            "LocationArn": location_arn,
            "Subdirectory": subdirectory,
            "User": user,
            "Domain": domain,
            "Password": password,
            "AgentArns": agent_arns,
            "MountOptions": mount_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more tags (key-value pairs) to the specified Amazon Location Service resource.  <p>Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only resources with certain tag values.</p> <p>You can use the <code>TagResource</code> operation with an Amazon Location Service resource that already has tags. If you specify a new tag key for the resource, this tag is appended to the tags already associated with the resource. If you specify a tag key that's already associated with the resource, the new tag value that you specify replaces the previous value for that tag. </p> <p>You can associate up to 50 tags with a resource.</p>

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource whose tags you want to update.   Format example: arn:aws:geo:region:account-id:resourcetype/ExampleResource   .
        tags(Dict): Tags that have been applied to the specified resource. Tags are mapped from the tag key to the tag value: "TagKey" : "TagValue".   Format example: {"tag1" : "value1", "tag2" : "value2"}    .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from the specified Amazon Location resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource from which you want to remove tags.   Format example: arn:aws:geo:region:account-id:resourcetype/ExampleResource   .
        tag_keys(List): The list of tag keys to remove from the specified resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    List the tags for an Amazon ECS resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the supported resources are Amazon ECS tasks, services, task definitions, clusters, and container instances.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_tags_for_resource",
        op_kwargs={"resourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    identity_pool_id: str,
    logins: Dict,
    identity_id: str = None,
    principal_tags: Dict = None,
    token_duration: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers (or retrieves) a Cognito IdentityId and an OpenID Connect token for a user authenticated by your backend authentication process. Supplying multiple logins will create an implicit linked account. You can only specify one developer provider as part of the Logins map, which is linked to the identity pool. The developer provider is the "domain" by which Cognito will refer to your users. You can use GetOpenIdTokenForDeveloperIdentity to create a new identity and to link new logins (that is, user credentials issued by a public provider or developer provider) to an existing identity. When you want to create a new identity, the IdentityId should be null. When you want to associate a new login with an existing authenticated/unauthenticated identity, you can do so by providing the existing IdentityId. This API will create the identity in the specified IdentityPoolId. You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.
        identity_id(str, optional): A unique identifier in the format REGION:GUID. Defaults to None.
        logins(Dict): A set of optional name-value pairs that map provider names to provider tokens. Each name-value pair represents a user from a public provider or developer provider. If the user is from a developer provider, the name-value pair will follow the syntax "developer_provider_name": "developer_user_identifier". The developer provider is the "domain" by which Cognito will refer to your users; you provided this domain while creating/updating the identity pool. The developer user identifier is an identifier from your backend that uniquely identifies a user. When you create an identity pool, you can specify the supported logins.
        principal_tags(Dict, optional): Use this operation to configure attribute mappings for custom providers. . Defaults to None.
        token_duration(int, optional): The expiration time of the token, in seconds. You can specify a custom expiration time for the token so that you can cache it. If you don't provide an expiration time, the token is valid for 15 minutes. You can exchange the token with Amazon STS for temporary AWS credentials, which are valid for a maximum of one hour. The maximum token duration you can set is 24 hours. You should take care in setting the expiration time for a token, as there are significant security implications: an attacker could use a leaked token to access your AWS resources for the token's duration.  Please provide for a small grace period, usually no more than 5 minutes, to account for clock skew. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.open_id_token.for_developer_identity.get(
                ctx, identity_pool_id=value, logins=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.open_id_token.for_developer_identity.get identity_pool_id=value, logins=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="get_open_id_token_for_developer_identity",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "Logins": logins,
            "PrincipalTags": principal_tags,
            "TokenDuration": token_duration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    accept_language: str = None,
    id_: str = None,
    name: str = None,
    source_portfolio_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified product. This operation is run with administrator access.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str, optional): The product identifier. Defaults to None.
        name(str, optional): The product name. Defaults to None.
        source_portfolio_id(str, optional): The unique identifier of the shared portfolio that the specified product is associated with. You can provide this parameter to retrieve the shared TagOptions associated with the product. If this parameter is provided and if TagOptions sharing is enabled in the portfolio share, the API returns both local and shared TagOptions associated with the product. Otherwise only local TagOptions will be returned. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.as_admin.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.as_admin.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_product_as_admin",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "Id": id_,
            "Name": name,
            "SourcePortfolioId": source_portfolio_id,
        },
    )


async def search(
    hub,
    ctx,
    accept_language: str = None,
    portfolio_id: str = None,
    filters: Dict = None,
    sort_by: str = None,
    sort_order: str = None,
    page_token: str = None,
    page_size: int = None,
    product_source: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the products for the specified portfolio or all products.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str, optional): The portfolio identifier. Defaults to None.
        filters(Dict, optional): The search filters. If no search filters are specified, the output includes all products to which the administrator has access. Defaults to None.
        sort_by(str, optional): The sort field. If no value is specified, the results are not sorted. Defaults to None.
        sort_order(str, optional): The sort order. If no value is specified, the results are not sorted. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        product_source(str, optional): Access level of the source of the product. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.as_admin.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.as_admin.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="search_products_as_admin",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "Filters": filters,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "PageToken": page_token,
            "PageSize": page_size,
            "ProductSource": product_source,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about recent sampling results for all sampling rules.

    Args:
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.sampling.statistic_summary.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.sampling.statistic_summary.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_sampling_statistic_summaries",
        op_kwargs={"NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    name: str,
    resources_vpc_config: Dict = None,
    logging: Dict = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Amazon EKS cluster configuration. Your cluster continues to function during the update. The response output includes an update ID that you can use to track the status of your cluster update with the DescribeUpdate API operation. You can use this API operation to enable or disable exporting the Kubernetes control plane logs for your cluster to CloudWatch Logs. By default, cluster control plane logs aren't exported to CloudWatch Logs. For more information, see Amazon EKS Cluster Control Plane Logs in the  Amazon EKS User Guide .  CloudWatch Logs ingestion, archive storage, and data scanning rates apply to exported control plane logs. For more information, see CloudWatch Pricing.  You can also use this API operation to enable or disable public and private access to your cluster's Kubernetes API server endpoint. By default, public access is enabled, and private access is disabled. For more information, see Amazon EKS cluster endpoint access control in the  Amazon EKS User Guide .   You can't update the subnets or security group IDs for an existing cluster.  Cluster updates are asynchronous, and they should finish within a few minutes. During an update, the cluster status moves to UPDATING (this status transition is eventually consistent). When the update is complete (either Failed or Successful), the cluster status moves to Active.

    Args:
        name(str): The name of the Amazon EKS cluster to update.
        resources_vpc_config(Dict, optional): An object representing the VPC configuration to use for an Amazon EKS cluster. Defaults to None.
        logging(Dict, optional): Enable or disable exporting the Kubernetes control plane logs for your cluster to CloudWatch Logs. By default, cluster control plane logs aren't exported to CloudWatch Logs. For more information, see Amazon EKS cluster control plane logs in the  Amazon EKS User Guide .  CloudWatch Logs ingestion, archive storage, and data scanning rates apply to exported control plane logs. For more information, see CloudWatch Pricing. . Defaults to None.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.cluster.config.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.cluster.config.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="update_cluster_config",
        op_kwargs={
            "name": name,
            "resourcesVpcConfig": resources_vpc_config,
            "logging": logging,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def define(hub, ctx, domain_name: str, expression: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Configures an Expression for the search domain. Used to create new expressions and modify existing ones. If the expression exists, the new configuration replaces the old one. For more information, see Configuring Expressions in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        expression(Dict): A named expression that can be evaluated at search time. Can be used to sort the search results, define other expressions, or return computed information in the search results. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.expression.define(
                ctx, domain_name=value, expression=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.expression.define domain_name=value, expression=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="define_expression",
        op_kwargs={"DomainName": domain_name, "Expression": expression},
    )


async def delete(hub, ctx, domain_name: str, expression_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an Expression from the search domain. For more information, see Configuring Expressions in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        expression_name(str): The name of the Expression to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.expression.delete(
                ctx, domain_name=value, expression_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.expression.delete domain_name=value, expression_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="delete_expression",
        op_kwargs={"DomainName": domain_name, "ExpressionName": expression_name},
    )


async def describe_all(
    hub, ctx, domain_name: str, expression_names: List = None, deployed: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the expressions configured for the search domain. Can be limited to specific expressions by name. By default, shows all expressions and includes any pending changes to the configuration. Set the Deployed option to true to show the active configuration and exclude pending changes. For more information, see Configuring Expressions in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): The name of the domain you want to describe.
        expression_names(List, optional): Limits the DescribeExpressions response to the specified expressions. If not specified, all expressions are shown. Defaults to None.
        deployed(bool, optional): Whether to display the deployed configuration (true) or include any pending changes (false). Defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.expression.describe_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.expression.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_expressions",
        op_kwargs={
            "DomainName": domain_name,
            "ExpressionNames": expression_names,
            "Deployed": deployed,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, input_identifier: Dict, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Lists one or more input routings.

    Args:
        input_identifier(Dict):  The identifer of the routed input. .
        max_results(int, optional):  The maximum number of results to be returned per request. . Defaults to None.
        next_token(str, optional):  The token that you can use to return the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.input_.routing.list_all(ctx, input_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.input_.routing.list_all input_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="list_input_routings",
        op_kwargs={
            "inputIdentifier": input_identifier,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    auto_scaling_group_name: str,
    policy_name: str,
    start_time: str,
    end_time: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the forecast data for a predictive scaling policy. Load forecasts are predictions of the hourly load values using historical load data from CloudWatch and an analysis of historical trends. Capacity forecasts are represented as predicted values for the minimum capacity that is needed on an hourly basis, based on the hourly load forecast. A minimum of 24 hours of data is required to create the initial forecasts. However, having a full 14 days of historical data results in more accurate forecasts. For more information, see Predictive scaling for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        policy_name(str): The name of the policy.
        start_time(str): The inclusive start time of the time range for the forecast data to get. At most, the date and time can be one year before the current date and time.
        end_time(str): The exclusive end time of the time range for the forecast data to get. The maximum time duration between the start and end time is 30 days.  Although this parameter can accept a date and time that is more than two days in the future, the availability of forecast data has limits. Amazon EC2 Auto Scaling only issues forecasts for periods of two days in advance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.predictive_scaling_forecast.get(
                ctx,
                auto_scaling_group_name=value,
                policy_name=value,
                start_time=value,
                end_time=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.predictive_scaling_forecast.get auto_scaling_group_name=value, policy_name=value, start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="get_predictive_scaling_forecast",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "PolicyName": policy_name,
            "StartTime": start_time,
            "EndTime": end_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, blacklist_item_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a list of the blacklists that your dedicated IP addresses appear on.

    Args:
        blacklist_item_names(List): A list of IP addresses that you want to retrieve blacklist information about. You can only specify the dedicated IP addresses that you use to send email using Amazon SES or Amazon Pinpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.blacklist_report.get_all(ctx, blacklist_item_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.blacklist_report.get_all blacklist_item_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_blacklist_reports",
        op_kwargs={"BlacklistItemNames": blacklist_item_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, image_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the permissions that the owner of an image has granted to other AWS accounts for an image.

    Args:
        image_id(str): The identifier of the image.
        next_token(str, optional): If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of items to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.image.permission.describe_all(
                ctx, image_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.image.permission.describe_all image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_workspace_image_permissions",
        op_kwargs={
            "ImageId": image_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, image_id: str, allow_copy_image: bool, shared_account_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Shares or unshares an image with one account in the same AWS Region by specifying whether that account has permission to copy the image. If the copy image permission is granted, the image is shared with that account. If the copy image permission is revoked, the image is unshared with the account. After an image has been shared, the recipient account can copy the image to other AWS Regions as needed.  In the China (Ningxia) Region, you can copy images only within the same Region. In the AWS GovCloud (US-West) Region, to copy images to and from other AWS Regions, contact AWS Support.  For more information about sharing images, see  Share or Unshare a Custom WorkSpaces Image.    To delete an image that has been shared, you must unshare the image before you delete it.   Sharing Bring Your Own License (BYOL) images across AWS accounts isn't supported at this time in the AWS GovCloud (US-West) Region. To share BYOL images across accounts in the AWS GovCloud (US-West) Region, contact AWS Support.

    Args:
        image_id(str): The identifier of the image.
        allow_copy_image(bool): The permission to copy the image. This permission can be revoked only after an image has been shared.
        shared_account_id(str): The identifier of the AWS account to share or unshare the image with.  Before sharing the image, confirm that you are sharing to the correct AWS account ID. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.image.permission.update(
                ctx, image_id=value, allow_copy_image=value, shared_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.image.permission.update image_id=value, allow_copy_image=value, shared_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="update_workspace_image_permission",
        op_kwargs={
            "ImageId": image_id,
            "AllowCopyImage": allow_copy_image,
            "SharedAccountId": shared_account_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, commit_ids: List, repository_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the contents of one or more commits in a repository.

    Args:
        commit_ids(List): The full commit IDs of the commits to get information about.  You must supply the full SHA IDs of each commit. You cannot use shortened SHA IDs. .
        repository_name(str): The name of the repository that contains the commits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.get.commit.batch(
                ctx, commit_ids=value, repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.get.commit.batch commit_ids=value, repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="batch_get_commits",
        op_kwargs={"commitIds": commit_ids, "repositoryName": repository_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    display_name: str = None,
    encryption_key: str = None,
    provisioning: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an environment template for AWS Proton. For more information, see Environment Templates in the AWS Proton Administrator Guide. You can create an environment template in one of the two following ways:   Register and publish a standard environment template that instructs AWS Proton to deploy and manage environment infrastructure.   Register and publish a customer managed environment template that connects AWS Proton to your existing provisioned infrastructure that you manage. AWS Proton doesn't manage your existing provisioned infrastructure. To create an environment template for customer provisioned and managed infrastructure, include the provisioning parameter and set the value to CUSTOMER_MANAGED. For more information, see Register and publish an environment template in the AWS Proton Administrator Guide.

    Args:
        description(str, optional): A description of the environment template. Defaults to None.
        display_name(str, optional): The environment template name as displayed in the developer interface. Defaults to None.
        encryption_key(str, optional): A customer provided encryption key that AWS Proton uses to encrypt data. Defaults to None.
        name(str): The name of the environment template.
        provisioning(str, optional): When included, indicates that the environment template is for customer provisioned and managed infrastructure. Defaults to None.
        tags(List, optional): Create tags for your environment template. For more information, see AWS Proton resources and tagging in the AWS Proton Administrator Guide or AWS Proton User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.template.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.template.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="create_environment_template",
        op_kwargs={
            "description": description,
            "displayName": display_name,
            "encryptionKey": encryption_key,
            "name": name,
            "provisioning": provisioning,
            "tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    If no other major or minor versions of an environment template exist, delete the environment template.

    Args:
        name(str): The name of the environment template to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.template.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.template.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="delete_environment_template",
        op_kwargs={"name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Get detail data for an environment template.

    Args:
        name(str): The name of the environment template that you want to get the detail data for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.template.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.template.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="get_environment_template",
        op_kwargs={"name": name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List environment templates.

    Args:
        max_results(int, optional): The maximum number of environment templates to list. Defaults to None.
        next_token(str, optional): A token to indicate the location of the next environment template in the array of environment templates, after the list of environment templates that was previously requested. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.template.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.template.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="list_environment_templates",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub, ctx, name: str, description: str = None, display_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update an environment template.

    Args:
        description(str, optional): A description of the environment template update. Defaults to None.
        display_name(str, optional): The name of the environment template to update as displayed in the developer interface. Defaults to None.
        name(str): The name of the environment template to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.template.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.template.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_environment_template",
        op_kwargs={
            "description": description,
            "displayName": display_name,
            "name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def update(hub, ctx, vtl_device_arn: str, device_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the type of medium changer in a tape gateway. When you activate a tape gateway, you select a medium changer type for the tape gateway. This operation enables you to select a different type of medium changer after a tape gateway is activated. This operation is only supported in the tape gateway type.

    Args:
        vtl_device_arn(str): The Amazon Resource Name (ARN) of the medium changer you want to select.
        device_type(str): The type of medium changer you want to select. Valid Values: STK-L700 | AWS-Gateway-VTL | IBM-03584L32-0402 .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.vtl_device.type_.update(
                ctx, vtl_device_arn=value, device_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.vtl_device.type.update vtl_device_arn=value, device_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_vtl_device_type",
        op_kwargs={"VTLDeviceARN": vtl_device_arn, "DeviceType": device_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, schema_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a paginated list of TypedLink facet names for a particular schema. For more information, see Typed Links.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the schema. For more information, see arns.
        next_token(str, optional): The pagination token. Defaults to None.
        max_results(int, optional): The maximum number of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.typed_link.facet.name.list_all(
                ctx, schema_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.typed_link.facet.name.list_all schema_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="list_typed_link_facet_names",
        op_kwargs={
            "SchemaArn": schema_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    replication_task_arn: str,
    max_records: int = None,
    marker: str = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns table statistics on the database migration task, including table name, rows inserted, rows updated, and rows deleted. Note that the "last updated" column the DMS console only indicates the time that DMS last updated the table statistics record for a table. It does not indicate the time of the last update to the table.

    Args:
        replication_task_arn(str): The Amazon Resource Name (ARN) of the replication task.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 500. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        filters(List, optional): Filters applied to table statistics. Valid filter names: schema-name | table-name | table-state A combination of filters creates an AND condition where each record matches all specified filters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.table.statistic.describe_all(
                ctx, replication_task_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.table.statistic.describe_all replication_task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_table_statistics",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "MaxRecords": max_records,
            "Marker": marker,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "change_set"


async def create(
    hub,
    ctx,
    stack_name: str,
    change_set_name: str,
    template_body: str = None,
    template_url: str = None,
    use_previous_template: bool = None,
    parameters: List = None,
    capabilities: List = None,
    resource_types: List = None,
    role_arn: str = None,
    rollback_configuration: Dict = None,
    notification_ar_ns: List = None,
    tags: List = None,
    client_token: str = None,
    description: str = None,
    change_set_type: str = None,
    resources_to_import: List = None,
    include_nested_stacks: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a list of changes that will be applied to a stack so that you can review the changes before executing them. You can create a change set for a stack that doesn't exist or an existing stack. If you create a change set for a stack that doesn't exist, the change set shows all of the resources that CloudFormation will create. If you create a change set for an existing stack, CloudFormation compares the stack's information with the information that you submit in the change set and lists the differences. Use change sets to understand which resources CloudFormation will create or change, and how it will change resources in an existing stack, before you create or update a stack. To create a change set for a stack that doesn't exist, for the ChangeSetType parameter, specify CREATE. To create a change set for an existing stack, specify UPDATE for the ChangeSetType parameter. To create a change set for an import operation, specify IMPORT for the ChangeSetType parameter. After the CreateChangeSet call successfully completes, CloudFormation starts creating the change set. To check the status of the change set or to review it, use the DescribeChangeSet action. When you are satisfied with the changes the change set will make, execute the change set by using the ExecuteChangeSet action. CloudFormation doesn't make changes until you execute the change set. To create a change set for the entire stack hierachy, set IncludeNestedStacks to True.

    Args:
        stack_name(str): The name or the unique ID of the stack for which you are creating a change set. CloudFormation generates the change set by comparing this stack's information with the information that you submit, such as a modified template or different parameter input values.
        template_body(str, optional): A structure that contains the body of the revised template, with a minimum length of 1 byte and a maximum length of 51,200 bytes. CloudFormation generates the change set by comparing this template with the template of the stack that you specified. Conditional: You must specify only TemplateBody or TemplateURL. Defaults to None.
        template_url(str, optional): The location of the file that contains the revised template. The URL must point to a template (max size: 460,800 bytes) that is located in an S3 bucket or a Systems Manager document. CloudFormation generates the change set by comparing this template with the stack that you specified. Conditional: You must specify only TemplateBody or TemplateURL. Defaults to None.
        use_previous_template(bool, optional): Whether to reuse the template that is associated with the stack to create the change set. Defaults to None.
        parameters(List, optional): A list of Parameter structures that specify input parameters for the change set. For more information, see the Parameter data type. Defaults to None.
        capabilities(List, optional): In some cases, you must explicitly acknowledge that your stack template contains certain capabilities in order for CloudFormation to create the stack.    CAPABILITY_IAM and CAPABILITY_NAMED_IAM  Some stack templates might include resources that can affect permissions in your account; for example, by creating new Identity and Access Management (IAM) users. For those stacks, you must explicitly acknowledge this by specifying one of these capabilities. The following IAM resources require you to specify either the CAPABILITY_IAM or CAPABILITY_NAMED_IAM capability.   If you have IAM resources, you can specify either capability.    If you have IAM resources with custom names, you must specify CAPABILITY_NAMED_IAM.    If you don't specify either of these capabilities, CloudFormation returns an InsufficientCapabilities error.   If your stack template contains these resources, we recommend that you review all permissions associated with them and edit their permissions if necessary.     AWS::IAM::AccessKey      AWS::IAM::Group      AWS::IAM::InstanceProfile      AWS::IAM::Policy      AWS::IAM::Role      AWS::IAM::User      AWS::IAM::UserToGroupAddition    For more information, see Acknowledging IAM Resources in CloudFormation Templates.    CAPABILITY_AUTO_EXPAND  Some template contain macros. Macros perform custom processing on templates; this can include simple actions like find-and-replace operations, all the way to extensive transformations of entire templates. Because of this, users typically create a change set from the processed template, so that they can review the changes resulting from the macros before actually creating the stack. If your stack template contains one or more macros, and you choose to create a stack directly from the processed template, without first reviewing the resulting changes in a change set, you must acknowledge this capability. This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.  This capacity does not apply to creating change sets, and specifying it when creating change sets has no effect. If you want to create a stack from a stack template that contains macros and nested stacks, you must create or update the stack directly from the template using the CreateStack or UpdateStack action, and specifying this capability.  For more information on macros, see Using CloudFormation Macros to Perform Custom Processing on Templates.  . Defaults to None.
        resource_types(List, optional): The template resource types that you have permissions to work with if you execute this change set, such as AWS::EC2::Instance, AWS::EC2::*, or Custom::MyCustomInstance. If the list of resource types doesn't include a resource type that you're updating, the stack update fails. By default, CloudFormation grants permissions to all resource types. Identity and Access Management (IAM) uses this parameter for condition keys in IAM policies for CloudFormation. For more information, see Controlling Access with Identity and Access Management in the CloudFormation User Guide. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of an Identity and Access Management (IAM) role that CloudFormation assumes when executing the change set. CloudFormation uses the role's credentials to make calls on your behalf. CloudFormation uses this role for all future operations on the stack. As long as users have permission to operate on the stack, CloudFormation uses this role even if the users don't have permission to pass it. Ensure that the role grants least privilege. If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials. Defaults to None.
        rollback_configuration(Dict, optional): The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards. Defaults to None.
        notification_ar_ns(List, optional): The Amazon Resource Names (ARNs) of Amazon Simple Notification Service (Amazon SNS) topics that CloudFormation associates with the stack. To remove all associated notification topics, specify an empty list. Defaults to None.
        tags(List, optional): Key-value pairs to associate with this stack. CloudFormation also propagates these tags to resources in the stack. You can specify a maximum of 50 tags. Defaults to None.
        change_set_name(str): The name of the change set. The name must be unique among all change sets that are associated with the specified stack. A change set name can contain only alphanumeric, case sensitive characters and hyphens. It must start with an alphabetic character and cannot exceed 128 characters.
        client_token(str, optional): A unique identifier for this CreateChangeSet request. Specify this token if you plan to retry requests so that CloudFormation knows that you're not attempting to create another change set with the same name. You might retry CreateChangeSet requests to ensure that CloudFormation successfully received them. Defaults to None.
        description(str, optional): A description to help you identify this change set. Defaults to None.
        change_set_type(str, optional): The type of change set operation. To create a change set for a new stack, specify CREATE. To create a change set for an existing stack, specify UPDATE. To create a change set for an import operation, specify IMPORT. If you create a change set for a new stack, CloudFormation creates a stack with a unique stack ID, but no template or resources. The stack will be in the  REVIEW_IN_PROGRESS  state until you execute the change set. By default, CloudFormation specifies UPDATE. You can't use the UPDATE type to create a change set for a new stack or the CREATE type to create a change set for an existing stack. Defaults to None.
        resources_to_import(List, optional): The resources to import into your stack. Defaults to None.
        include_nested_stacks(bool, optional): Creates a change set for the all nested stacks specified in the template. The default behavior of this action is set to False. To include nested sets in a change set, specify True. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.change_set_.create(
                ctx, stack_name=value, change_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.change_set.create stack_name=value, change_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="create_change_set",
        op_kwargs={
            "StackName": stack_name,
            "TemplateBody": template_body,
            "TemplateURL": template_url,
            "UsePreviousTemplate": use_previous_template,
            "Parameters": parameters,
            "Capabilities": capabilities,
            "ResourceTypes": resource_types,
            "RoleARN": role_arn,
            "RollbackConfiguration": rollback_configuration,
            "NotificationARNs": notification_ar_ns,
            "Tags": tags,
            "ChangeSetName": change_set_name,
            "ClientToken": client_token,
            "Description": description,
            "ChangeSetType": change_set_type,
            "ResourcesToImport": resources_to_import,
            "IncludeNestedStacks": include_nested_stacks,
        },
    )


async def delete(hub, ctx, change_set_name: str, stack_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified change set. Deleting change sets ensures that no one executes the wrong change set. If the call successfully completes, CloudFormation successfully deleted the change set. If IncludeNestedStacks specifies True during the creation of the nested change set, then DeleteChangeSet will delete all change sets that belong to the stacks hierarchy and will also delete all change sets for nested stacks with the status of REVIEW_IN_PROGRESS.

    Args:
        change_set_name(str): The name or Amazon Resource Name (ARN) of the change set that you want to delete.
        stack_name(str, optional): If you specified the name of a change set to delete, specify the stack name or ID (ARN) that is associated with it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.change_set_.delete(ctx, change_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.change_set.delete change_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="delete_change_set",
        op_kwargs={"ChangeSetName": change_set_name, "StackName": stack_name},
    )


async def describe(
    hub, ctx, change_set_name: str, stack_name: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the inputs for the change set and a list of changes that CloudFormation will make if you execute the change set. For more information, see Updating Stacks Using Change Sets in the CloudFormation User Guide.

    Args:
        change_set_name(str): The name or Amazon Resource Name (ARN) of the change set that you want to describe.
        stack_name(str, optional): If you specified the name of a change set, specify the stack name or ID (ARN) of the change set you want to describe. Defaults to None.
        next_token(str, optional): A string (provided by the DescribeChangeSet response output) that identifies the next page of information that you want to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.change_set_.describe(ctx, change_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.change_set.describe change_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_change_set",
        op_kwargs={
            "ChangeSetName": change_set_name,
            "StackName": stack_name,
            "NextToken": next_token,
        },
    )


async def execute(
    hub,
    ctx,
    change_set_name: str,
    stack_name: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a stack using the input information that was provided when the specified change set was created. After the call successfully completes, CloudFormation starts updating the stack. Use the DescribeStacks action to view the status of the update. When you execute a change set, CloudFormation deletes all other change sets associated with the stack because they aren't valid for the updated stack. If a stack policy is associated with the stack, CloudFormation enforces the policy during the update. You can't specify a temporary stack policy that overrides the current policy. To create a change set for the entire stack hierachy, IncludeNestedStacks must have been set to True.

    Args:
        change_set_name(str): The name or ARN of the change set that you want use to update the specified stack.
        stack_name(str, optional): If you specified the name of a change set, specify the stack name or ID (ARN) that is associated with the change set you want to execute. Defaults to None.
        client_request_token(str, optional): A unique identifier for this ExecuteChangeSet request. Specify this token if you plan to retry requests so that CloudFormation knows that you're not attempting to execute a change set to update a stack with the same name. You might retry ExecuteChangeSet requests to ensure that CloudFormation successfully received them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.change_set_.execute(ctx, change_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.change_set.execute change_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="execute_change_set",
        op_kwargs={
            "ChangeSetName": change_set_name,
            "StackName": stack_name,
            "ClientRequestToken": client_request_token,
        },
    )


async def list_all(hub, ctx, stack_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the ID and status of each active change set for a stack. For example, CloudFormation lists change sets that are in the CREATE_IN_PROGRESS or CREATE_PENDING state.

    Args:
        stack_name(str): The name or the Amazon Resource Name (ARN) of the stack for which you want to list change sets.
        next_token(str, optional): A string (provided by the ListChangeSets response output) that identifies the next page of change sets that you want to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.change_set_.list_all(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.change_set.list_all stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_change_sets",
        op_kwargs={"StackName": stack_name, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    connection_id: str,
    secret_arn: str = None,
    ckn: str = None,
    cak: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a MAC Security (MACsec) Connection Key Name (CKN)/ Connectivity Association Key (CAK) pair with an Direct Connect dedicated connection. You must supply either the secretARN, or the CKN/CAK (ckn and cak) pair in the request. For information about MAC Security (MACsec) key considerations, see MACsec pre-shared CKN/CAK key considerations  in the Direct Connect User Guide.

    Args:
        connection_id(str): The ID of the dedicated connection (dxcon-xxxx), or the ID of the LAG (dxlag-xxxx). You can use DescribeConnections or DescribeLags to retrieve connection ID.
        secret_arn(str, optional): The Amazon Resource Name (ARN) of the MAC Security (MACsec) secret key to associate with the dedicated connection. You can use DescribeConnections or DescribeLags to retrieve the MAC Security (MACsec) secret key. If you use this request parameter, you do not use the ckn and cak request parameters. Defaults to None.
        ckn(str, optional): The MAC Security (MACsec) CKN to associate with the dedicated connection. You can create the CKN/CAK pair using an industry standard tool.  The valid values are 64 hexadecimal characters (0-9, A-E). If you use this request parameter, you must use the cak request parameter and not use the secretARN request parameter. Defaults to None.
        cak(str, optional): The MAC Security (MACsec) CAK to associate with the dedicated connection. You can create the CKN/CAK pair using an industry standard tool.  The valid values are 64 hexadecimal characters (0-9, A-E). If you use this request parameter, you must use the ckn request parameter and not use the secretARN request parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.mac_sec_key.associate(ctx, connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.mac_sec_key.associate connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="associate_mac_sec_key",
        op_kwargs={
            "connectionId": connection_id,
            "secretARN": secret_arn,
            "ckn": ckn,
            "cak": cak,
        },
    )


async def disassociate(hub, ctx, connection_id: str, secret_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the association between a MAC Security (MACsec) security key and an Direct Connect dedicated connection.

    Args:
        connection_id(str): The ID of the dedicated connection (dxcon-xxxx), or the ID of the LAG (dxlag-xxxx). You can use DescribeConnections or DescribeLags to retrieve connection ID.
        secret_arn(str): The Amazon Resource Name (ARN) of the MAC Security (MACsec) secret key. You can use DescribeConnections to retrieve the ARN of the MAC Security (MACsec) secret key.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.mac_sec_key.disassociate(
                ctx, connection_id=value, secret_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.mac_sec_key.disassociate connection_id=value, secret_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="disassociate_mac_sec_key",
        op_kwargs={"connectionId": connection_id, "secretARN": secret_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    time_period: Dict,
    search_string: str = None,
    tag_key: str = None,
    filter_: Dict = None,
    sort_by: List = None,
    max_results: int = None,
    next_page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Queries for available tag keys and tag values for a specified period. You can search the tag values for an arbitrary string.

    Args:
        search_string(str, optional): The value that you want to search for. Defaults to None.
        time_period(Dict): The start and end dates for retrieving the dimension values. The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01.
        tag_key(str, optional): The key of the tag that you want to return values for. Defaults to None.
        filter_(Dict, optional): Use Expression to filter by cost or by usage. There are two patterns:    Simple dimension values - You can set the dimension name and values for the filters that you plan to use. For example, you can filter for REGION==us-east-1 OR REGION==us-west-1. For GetRightsizingRecommendation, the Region is a full name (for example, REGION==US East (N. Virginia). The Expression example looks like:  { "Dimensions": { "Key": "REGION", "Values": [ "us-east-1", “us-west-1” ] } }  The list of dimension values are OR'd together to retrieve cost or usage data. You can create Expression and DimensionValues objects using either with* methods or set* methods in multiple lines.    Compound dimension values with logical operations - You can use multiple Expression types and the logical operators AND/OR/NOT to create a list of one or more Expression objects. This allows you to filter on more advanced options. For example, you can filter on ((REGION == us-east-1 OR REGION == us-west-1) OR (TAG.Type == Type1)) AND (USAGE_TYPE != DataTransfer). The Expression for that looks like this:  { "And": [ {"Or": [ {"Dimensions": { "Key": "REGION", "Values": [ "us-east-1", "us-west-1" ] }}, {"Tags": { "Key": "TagName", "Values": ["Value1"] } } ]}, {"Not": {"Dimensions": { "Key": "USAGE_TYPE", "Values": ["DataTransfer"] }}} ] }    Because each Expression can have only one operator, the service returns an error if more than one is specified. The following example shows an Expression object that creates an error.    { "And": [ ... ], "DimensionValues": { "Dimension": "USAGE_TYPE", "Values": [ "DataTransfer" ] } }      For the GetRightsizingRecommendation action, a combination of OR and NOT is not supported. OR is not supported between different dimensions, or dimensions and tags. NOT operators aren't supported. Dimensions are also limited to LINKED_ACCOUNT, REGION, or RIGHTSIZING_TYPE. For the GetReservationPurchaseRecommendation action, only NOT is supported. AND and OR are not supported. Dimensions are limited to LINKED_ACCOUNT. . Defaults to None.
        sort_by(List, optional): The value by which you want to sort the data. The key represents cost and usage metrics. The following values are supported:    BlendedCost     UnblendedCost     AmortizedCost     NetAmortizedCost     NetUnblendedCost     UsageQuantity     NormalizedUsageAmount    Supported values for SortOrder are ASCENDING or DESCENDING. When using SortBy, NextPageToken and SearchString are not supported. Defaults to None.
        max_results(int, optional): This field is only used when SortBy is provided in the request. The maximum number of objects that to be returned for this request. If MaxResults is not specified with SortBy, the request will return 1000 results as the default value for this parameter. For GetTags, MaxResults has an upper limit of 1000. Defaults to None.
        next_page_token(str, optional): The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.tags.get(ctx, time_period=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.tags.get time_period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_tags",
        op_kwargs={
            "SearchString": search_string,
            "TimePeriod": time_period,
            "TagKey": tag_key,
            "Filter": filter_,
            "SortBy": sort_by,
            "MaxResults": max_results,
            "NextPageToken": next_page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, budget_name: str, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified budget with the specified resource.

    Args:
        budget_name(str): The name of the budget you want to associate.
        resource_id(str):  The resource identifier. Either a portfolio-id or a product-id.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.budget.with_resource.associate(
                ctx, budget_name=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.budget.with_resource.associate budget_name=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="associate_budget_with_resource",
        op_kwargs={"BudgetName": budget_name, "ResourceId": resource_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def restore(
    hub,
    ctx,
    prefix_list_id: str,
    previous_version: int,
    current_version: int,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Restores the entries from a previous version of a managed prefix list to a new version of the prefix list.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        prefix_list_id(str): The ID of the prefix list.
        previous_version(int): The version to restore.
        current_version(int): The current version number for the prefix list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.managed_prefix_list_.version.restore(
                ctx, prefix_list_id=value, previous_version=value, current_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.managed_prefix_list_.version.restore prefix_list_id=value, previous_version=value, current_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="restore_managed_prefix_list_version",
        op_kwargs={
            "DryRun": dry_run,
            "PrefixListId": prefix_list_id,
            "PreviousVersion": previous_version,
            "CurrentVersion": current_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    thing_name: str,
    status_details: Dict = None,
    step_timeout_in_minutes: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution for a thing.

    Args:
        thing_name(str): The name of the thing associated with the device.
        status_details(Dict, optional): A collection of name/value pairs that describe the status of the job execution. If not specified, the statusDetails are unchanged. Defaults to None.
        step_timeout_in_minutes(int, optional): Specifies the amount of time this device has to finish execution of this job. If the job execution status is not set to a terminal state before this timer expires, or before the timer is reset (by calling UpdateJobExecution, setting the status to IN_PROGRESS and specifying a new timeout value in field stepTimeoutInMinutes) the job execution status will be automatically set to TIMED_OUT. Note that setting this timeout has no effect on that job execution timeout which may have been specified when the job was created (CreateJob using field timeoutConfig). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_jobs_data.next_pending_job_execution.start(
                ctx, thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_jobs_data.next_pending_job_execution.start thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-jobs-data",
        operation="start_next_pending_job_execution",
        op_kwargs={
            "thingName": thing_name,
            "statusDetails": status_details,
            "stepTimeoutInMinutes": step_timeout_in_minutes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, app_id: str, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Starts an on-demand replication run for the specified application.

    Args:
        app_id(str): The ID of the application.
        description(str, optional): The description of the replication run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.on_demand.app_replication.start(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.on_demand.app_replication.start app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="start_on_demand_app_replication",
        op_kwargs={"appId": app_id, "description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, domain_name: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a domain resource for the specified domain (e.g., example.com). The create domain operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        domain_name(str): The domain name to manage (e.g., example.com).  You cannot register a new domain name using Lightsail. You must register a domain name using Amazon Route 53 or another domain name registrar. If you have already registered your domain, you can enter its name in this parameter to manage the DNS records for that domain using Lightsail. .
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.domain.init.create(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.domain.init.create domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_domain",
        op_kwargs={"domainName": domain_name, "tags": tags},
    )


async def delete(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified domain recordset and all of its domain records. The delete domain operation supports tag-based access control via resource tags applied to the resource identified by domain name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        domain_name(str): The specific domain name to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.domain.init.delete(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.domain.init.delete domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_domain",
        op_kwargs={"domainName": domain_name},
    )


async def get(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific domain recordset.

    Args:
        domain_name(str): The domain name for which your want to return information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.domain.init.get(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.domain.init.get domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_domain",
        op_kwargs={"domainName": domain_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all domains in the user's account.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetDomains request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.domain.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.domain.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_domains",
        op_kwargs={"pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, schema_id: Dict, schema_definition: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a schema by the SchemaDefinition. The schema definition is sent to the Schema Registry, canonicalized, and hashed. If the hash is matched within the scope of the SchemaName or ARN (or the default registry, if none is supplied), that schema’s metadata is returned. Otherwise, a 404 or NotFound error is returned. Schema versions in Deleted statuses will not be included in the results.

    Args:
        schema_id(Dict): This is a wrapper structure to contain schema identity fields. The structure contains:   SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of SchemaArn or SchemaName has to be provided.   SchemaId$SchemaName: The name of the schema. One of SchemaArn or SchemaName has to be provided.  .
        schema_definition(str): The definition of the schema for which schema details are required.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.by_definition.get(
                ctx, schema_id=value, schema_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.by_definition.get schema_id=value, schema_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_schema_by_definition",
        op_kwargs={"SchemaId": schema_id, "SchemaDefinition": schema_definition},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def describe(hub, ctx, identity_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets usage details (for example, data storage) about a particular identity pool. This API can only be called with developer credentials. You cannot call this API with the temporary user credentials provided by Cognito Identity.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.identity.pool.usage.describe(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.identity.pool.usage.describe identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="describe_identity_pool_usage",
        op_kwargs={"IdentityPoolId": identity_pool_id},
    )


async def list_(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of identity pools registered with Cognito. ListIdentityPoolUsage can only be called with developer credentials. You cannot make this API call with the temporary user credentials provided by Cognito Identity.

    Args:
        next_token(str, optional): A pagination token for obtaining the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.identity.pool.usage.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.identity.pool.usage.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="list_identity_pool_usage",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subject: str,
    communication_body: str,
    service_code: str = None,
    severity_code: str = None,
    category_code: str = None,
    cc_email_addresses: List = None,
    language: str = None,
    issue_type: str = None,
    attachment_set_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a case in the AWS Support Center. This operation is similar to how you create a case in the AWS Support Center Create Case page. The AWS Support API doesn't support requesting service limit increases. You can submit a service limit increase in the following ways:    Submit a request from the AWS Support Center Create Case page.   Use the Service Quotas RequestServiceQuotaIncrease operation.   A successful CreateCase request returns an AWS Support case number. You can use the DescribeCases operation and specify the case number to get existing AWS Support cases. After you create a case, use the AddCommunicationToCase operation to add additional communication or attachments to an existing case. The caseId is separate from the displayId that appears in the AWS Support Center. Use the DescribeCases operation to get the displayId.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        subject(str): The title of the support case. The title appears in the Subject field on the AWS Support Center Create Case page.
        service_code(str, optional): The code for the AWS service. You can use the DescribeServices operation to get the possible serviceCode values. Defaults to None.
        severity_code(str, optional): A value that indicates the urgency of the case. This value determines the response time according to your service level agreement with AWS Support. You can use the DescribeSeverityLevels operation to get the possible values for severityCode.  For more information, see SeverityLevel and Choosing a Severity in the AWS Support User Guide.  The availability of severity levels depends on the support plan for the AWS account. . Defaults to None.
        category_code(str, optional): The category of problem for the support case. You also use the DescribeServices operation to get the category code for a service. Each AWS service defines its own set of category codes. Defaults to None.
        communication_body(str): The communication body text that describes the issue. This text appears in the Description field on the AWS Support Center Create Case page.
        cc_email_addresses(List, optional): A list of email addresses that AWS Support copies on case correspondence. AWS Support identifies the account that creates the case when you specify your AWS credentials in an HTTP POST method or use the AWS SDKs. . Defaults to None.
        language(str, optional): The language in which AWS Support handles the case. You must specify the ISO 639-1 code for the language parameter if you want support in that language. Currently, English ("en") and Japanese ("ja") are supported. Defaults to None.
        issue_type(str, optional): The type of issue for the case. You can specify customer-service or technical. If you don't specify a value, the default is technical. Defaults to None.
        attachment_set_id(str, optional): The ID of a set of one or more attachments for the case. Create the set by using the AddAttachmentsToSet operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.case.create(
                ctx, subject=value, communication_body=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.case.create subject=value, communication_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="create_case",
        op_kwargs={
            "subject": subject,
            "serviceCode": service_code,
            "severityCode": severity_code,
            "categoryCode": category_code,
            "communicationBody": communication_body,
            "ccEmailAddresses": cc_email_addresses,
            "language": language,
            "issueType": issue_type,
            "attachmentSetId": attachment_set_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    case_id_list: List = None,
    display_id: str = None,
    after_time: str = None,
    before_time: str = None,
    include_resolved_cases: bool = None,
    next_token: str = None,
    max_results: int = None,
    language: str = None,
    include_communications: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of cases that you specify by passing one or more case IDs. You can use the afterTime and beforeTime parameters to filter the cases by date. You can set values for the includeResolvedCases and includeCommunications parameters to specify how much information to return. The response returns the following in JSON format:   One or more CaseDetails data types.   One or more nextToken values, which specify where to paginate the returned records represented by the CaseDetails objects.   Case data is available for 12 months after creation. If a case was created more than 12 months ago, a request might return an error.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        case_id_list(List, optional): A list of ID numbers of the support cases you want returned. The maximum number of cases is 100. Defaults to None.
        display_id(str, optional): The ID displayed for a case in the AWS Support Center user interface. Defaults to None.
        after_time(str, optional): The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation. Defaults to None.
        before_time(str, optional): The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation. Defaults to None.
        include_resolved_cases(bool, optional): Specifies whether to include resolved support cases in the DescribeCases response. By default, resolved cases aren't included. Defaults to None.
        next_token(str, optional): A resumption point for pagination. Defaults to None.
        max_results(int, optional): The maximum number of results to return before paginating. Defaults to None.
        language(str, optional): The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them. Defaults to None.
        include_communications(bool, optional): Specifies whether to include communications in the DescribeCases response. By default, communications are included. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.case.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.case.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_cases",
        op_kwargs={
            "caseIdList": case_id_list,
            "displayId": display_id,
            "afterTime": after_time,
            "beforeTime": before_time,
            "includeResolvedCases": include_resolved_cases,
            "nextToken": next_token,
            "maxResults": max_results,
            "language": language,
            "includeCommunications": include_communications,
        },
    )


async def resolve(hub, ctx, case_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Resolves a support case. This operation takes a caseId and returns the initial and final state of the case.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        case_id(str, optional): The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47 . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.case.resolve(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.case.resolve
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="resolve_case",
        op_kwargs={"caseId": case_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, batch: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a simulation job batch. When you cancel a simulation job batch, you are also cancelling all of the active simulation jobs created as part of the batch.

    Args:
        batch(str): The id of the batch to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.batch.cancel(ctx, batch=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.batch.cancel batch=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="cancel_simulation_job_batch",
        op_kwargs={"batch": batch},
    )


async def describe(hub, ctx, batch: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a simulation job batch.

    Args:
        batch(str): The id of the batch to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.batch.describe(ctx, batch=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.batch.describe batch=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_simulation_job_batch",
        op_kwargs={"batch": batch},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list simulation job batches. You can optionally provide filters to retrieve specific simulation batch jobs.

    Args:
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListSimulationJobBatches again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListSimulationJobBatches only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListSimulationJobBatches request with the returned nextToken value. . Defaults to None.
        filters(List, optional): Optional filters to limit results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.batch.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.batch.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_simulation_job_batches",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "filters": filters,
        },
    )


async def start(
    hub,
    ctx,
    create_simulation_job_requests: List,
    client_request_token: str = None,
    batch_policy: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a new simulation job batch. The batch is defined using one or more SimulationJobRequest objects.

    Args:
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        batch_policy(Dict, optional): The batch policy. Defaults to None.
        create_simulation_job_requests(List): A list of simulation job requests to create in the batch.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the deployment job batch. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.batch.start(
                ctx, create_simulation_job_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.batch.start create_simulation_job_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="start_simulation_job_batch",
        op_kwargs={
            "clientRequestToken": client_request_token,
            "batchPolicy": batch_policy,
            "createSimulationJobRequests": create_simulation_job_requests,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, source_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists all LaunchConfigurations available, filtered by Source Server IDs.

    Args:
        source_server_id(str): Request to get Launch Configuration information by Source Server ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.launch_configuration.get(ctx, source_server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.launch_configuration.get source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="get_launch_configuration",
        op_kwargs={"sourceServerID": source_server_id},
    )


async def update(
    hub,
    ctx,
    source_server_id: str,
    copy_private_ip: bool = None,
    copy_tags: bool = None,
    launch_disposition: str = None,
    licensing: Dict = None,
    name: str = None,
    target_instance_type_right_sizing_method: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates multiple LaunchConfigurations by Source Server ID.

    Args:
        copy_private_ip(bool, optional): Update Launch configuration copy Private IP request. Defaults to None.
        copy_tags(bool, optional): Update Launch configuration copy Tags request. Defaults to None.
        launch_disposition(str, optional): Update Launch configuration launch disposition request. Defaults to None.
        licensing(Dict, optional): Update Launch configuration licensing request. Defaults to None.
        name(str, optional): Update Launch configuration name request. Defaults to None.
        source_server_id(str): Update Launch configuration by Source Server ID request.
        target_instance_type_right_sizing_method(str, optional): Update Launch configuration Target instance right sizing request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.launch_configuration.update(ctx, source_server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.launch_configuration.update source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="update_launch_configuration",
        op_kwargs={
            "copyPrivateIp": copy_private_ip,
            "copyTags": copy_tags,
            "launchDisposition": launch_disposition,
            "licensing": licensing,
            "name": name,
            "sourceServerID": source_server_id,
            "targetInstanceTypeRightSizingMethod": target_instance_type_right_sizing_method,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified tags to the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each AWS resource, up to 50 tags for a resource. You can tag the AWS resources that you manage through AWS Network Firewall: firewalls, firewall policies, and rule groups.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tags(List): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.resource.init.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.resource.init.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the tags with the specified keys from the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each AWS resource, up to 50 tags for a resource. You can manage tags for the AWS resources that you manage through AWS Network Firewall: firewalls, firewall policies, and rule groups.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tag_keys(List): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.resource.init.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.resource.init.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, analysis_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves one or more analysis results of the detector model.  After AWS IoT Events starts analyzing your detector model, you have up to 24 hours to retrieve the analysis results.

    Args:
        analysis_id(str): The ID of the analysis result that you want to retrieve.
        next_token(str, optional): The token that you can use to return the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.analysis.result.get_all(
                ctx, analysis_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.analysis.result.get_all analysis_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="get_detector_model_analysis_results",
        op_kwargs={
            "analysisId": analysis_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    stack_id: str,
    command: Dict,
    app_id: str = None,
    instance_ids: List = None,
    layer_ids: List = None,
    comment: str = None,
    custom_json: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs deployment or stack commands. For more information, see Deploying Apps and Run Stack Commands.  Required Permissions: To use this action, an IAM user must have a Deploy or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
        app_id(str, optional): The app ID. This parameter is required for app deployments, but not for other deployment commands. Defaults to None.
        instance_ids(List, optional): The instance IDs for the deployment targets. Defaults to None.
        layer_ids(List, optional): The layer IDs for the deployment targets. Defaults to None.
        command(Dict): A DeploymentCommand object that specifies the deployment command and any associated arguments.
        comment(str, optional): A user-defined comment. Defaults to None.
        custom_json(str, optional): A string that contains user-defined, custom JSON. You can use this parameter to override some corresponding default stack configuration JSON values. The string should be in the following format:  "{\"key1\": \"value1\", \"key2\": \"value2\",...}"  For more information about custom JSON, see Use Custom JSON to Modify the Stack Configuration Attributes and Overriding Attributes With Custom JSON. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.deployment.create(ctx, stack_id=value, command=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.deployment.create stack_id=value, command=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="create_deployment",
        op_kwargs={
            "StackId": stack_id,
            "AppId": app_id,
            "InstanceIds": instance_ids,
            "LayerIds": layer_ids,
            "Command": command,
            "Comment": comment,
            "CustomJson": custom_json,
        },
    )


async def describe_all(
    hub, ctx, stack_id: str = None, app_id: str = None, deployment_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Requests a description of a specified set of deployments.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        stack_id(str, optional): The stack ID. If you include this parameter, the command returns a description of the commands associated with the specified stack. Defaults to None.
        app_id(str, optional): The app ID. If you include this parameter, the command returns a description of the commands associated with the specified app. Defaults to None.
        deployment_ids(List, optional): An array of deployment IDs to be described. If you include this parameter, the command returns a description of the specified deployments. Otherwise, it returns a description of every deployment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.deployment.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.deployment.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_deployments",
        op_kwargs={
            "StackId": stack_id,
            "AppId": app_id,
            "DeploymentIds": deployment_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def deprecate(hub, ctx, domain: str, activity_type: Dict) -> None:
    r"""
    **Autogenerated function**

    Deprecates the specified activity type. After an activity type has been deprecated, you cannot create new tasks of that activity type. Tasks of this type that were scheduled before the type was deprecated continue to run.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    activityType.name: String constraint. The key is swf:activityType.name.    activityType.version: String constraint. The key is swf:activityType.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which the activity type is registered.
        activity_type(Dict): The activity type to deprecate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.activity.type_.deprecate(
                ctx, domain=value, activity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.activity.type.deprecate domain=value, activity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="deprecate_activity_type",
        op_kwargs={"domain": domain, "activityType": activity_type},
    )


async def describe(hub, ctx, domain: str, activity_type: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified activity type. This includes configuration settings provided when the type was registered and other general information about the type.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    activityType.name: String constraint. The key is swf:activityType.name.    activityType.version: String constraint. The key is swf:activityType.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which the activity type is registered.
        activity_type(Dict): The activity type to get information about. Activity types are identified by the name and version that were supplied when the activity was registered.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.activity.type_.describe(
                ctx, domain=value, activity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.activity.type.describe domain=value, activity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="describe_activity_type",
        op_kwargs={"domain": domain, "activityType": activity_type},
    )


async def list_all(
    hub,
    ctx,
    domain: str,
    registration_status: str,
    name: str = None,
    next_page_token: str = None,
    maximum_page_size: int = None,
    reverse_order: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all activities registered in the specified domain that match the specified name and registration status. The result includes information like creation date, current status of the activity, etc. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which the activity types have been registered.
        name(str, optional): If specified, only lists the activity types that have this name. Defaults to None.
        registration_status(str): Specifies the registration status of the activity types to list.
        next_page_token(str, optional): If NextPageToken is returned there are more results available. The value of NextPageToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 60 seconds. Using an expired pagination token will return a 400 error: "Specified token has exceeded its maximum lifetime".  The configured maximumPageSize determines how many results can be returned in a single call. . Defaults to None.
        maximum_page_size(int, optional): The maximum number of results that are returned per call. Use nextPageToken to obtain further pages of results. . Defaults to None.
        reverse_order(bool, optional): When set to true, returns the results in reverse order. By default, the results are returned in ascending alphabetical order by name of the activity types. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.activity.type_.list_all(
                ctx, domain=value, registration_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.activity.type.list_all domain=value, registration_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="list_activity_types",
        op_kwargs={
            "domain": domain,
            "name": name,
            "registrationStatus": registration_status,
            "nextPageToken": next_page_token,
            "maximumPageSize": maximum_page_size,
            "reverseOrder": reverse_order,
        },
    )


async def register(
    hub,
    ctx,
    domain: str,
    name: str,
    version: str,
    description: str = None,
    default_task_start_to_close_timeout: str = None,
    default_task_heartbeat_timeout: str = None,
    default_task_list: Dict = None,
    default_task_priority: str = None,
    default_task_schedule_to_start_timeout: str = None,
    default_task_schedule_to_close_timeout: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Registers a new activity type along with its configuration settings in the specified domain.  A TypeAlreadyExists fault is returned if the type already exists in the domain. You cannot change any configuration settings of the type after its registration, and it must be registered as a new version.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    defaultTaskList.name: String constraint. The key is swf:defaultTaskList.name.    name: String constraint. The key is swf:name.    version: String constraint. The key is swf:version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which this activity is to be registered.
        name(str): The name of the activity type within the domain. The specified string must not start or end with whitespace. It must not contain a : (colon), / (slash), | (vertical bar), or any control characters (\u0000-\u001f | \u007f-\u009f). Also, it must not be the literal string arn.
        version(str): The version of the activity type.  The activity type consists of the name and version, the combination of which must be unique within the domain.  The specified string must not start or end with whitespace. It must not contain a : (colon), / (slash), | (vertical bar), or any control characters (\u0000-\u001f | \u007f-\u009f). Also, it must not be the literal string arn.
        description(str, optional): A textual description of the activity type. Defaults to None.
        default_task_start_to_close_timeout(str, optional): If set, specifies the default maximum duration that a worker can take to process tasks of this activity type. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. The duration is specified in seconds, an integer greater than or equal to 0. You can use NONE to specify unlimited duration. Defaults to None.
        default_task_heartbeat_timeout(str, optional): If set, specifies the default maximum time before which a worker processing a task of this type must report progress by calling RecordActivityTaskHeartbeat. If the timeout is exceeded, the activity task is automatically timed out. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. If the activity worker subsequently attempts to record a heartbeat or returns a result, the activity worker receives an UnknownResource fault. In this case, Amazon SWF no longer considers the activity task to be valid; the activity worker should clean up the activity task. The duration is specified in seconds, an integer greater than or equal to 0. You can use NONE to specify unlimited duration. Defaults to None.
        default_task_list(Dict, optional): If set, specifies the default task list to use for scheduling tasks of this activity type. This default task list is used if a task list isn't provided when a task is scheduled through the ScheduleActivityTask Decision. Defaults to None.
        default_task_priority(str, optional): The default task priority to assign to the activity type. If not assigned, then 0 is used. Valid values are integers that range from Java's Integer.MIN_VALUE (-2147483648) to Integer.MAX_VALUE (2147483647). Higher numbers indicate higher priority. For more information about setting task priority, see Setting Task Priority in the in the Amazon SWF Developer Guide.. Defaults to None.
        default_task_schedule_to_start_timeout(str, optional): If set, specifies the default maximum duration that a task of this activity type can wait before being assigned to a worker. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. The duration is specified in seconds, an integer greater than or equal to 0. You can use NONE to specify unlimited duration. Defaults to None.
        default_task_schedule_to_close_timeout(str, optional): If set, specifies the default maximum duration for a task of this activity type. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. The duration is specified in seconds, an integer greater than or equal to 0. You can use NONE to specify unlimited duration. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.activity.type_.register(
                ctx, domain=value, name=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.activity.type.register domain=value, name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="register_activity_type",
        op_kwargs={
            "domain": domain,
            "name": name,
            "version": version,
            "description": description,
            "defaultTaskStartToCloseTimeout": default_task_start_to_close_timeout,
            "defaultTaskHeartbeatTimeout": default_task_heartbeat_timeout,
            "defaultTaskList": default_task_list,
            "defaultTaskPriority": default_task_priority,
            "defaultTaskScheduleToStartTimeout": default_task_schedule_to_start_timeout,
            "defaultTaskScheduleToCloseTimeout": default_task_schedule_to_close_timeout,
        },
    )


async def undeprecate(hub, ctx, domain: str, activity_type: Dict) -> None:
    r"""
    **Autogenerated function**

    Undeprecates a previously deprecated activity type. After an activity type has been undeprecated, you can create new tasks of that activity type.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    activityType.name: String constraint. The key is swf:activityType.name.    activityType.version: String constraint. The key is swf:activityType.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain of the deprecated activity type.
        activity_type(Dict): The activity type to undeprecate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.activity.type_.undeprecate(
                ctx, domain=value, activity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.activity.type.undeprecate domain=value, activity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="undeprecate_activity_type",
        op_kwargs={"domain": domain, "activityType": activity_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, file_system_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current LifecycleConfiguration object for the specified Amazon EFS file system. EFS lifecycle management uses the LifecycleConfiguration object to identify which files to move to the EFS Infrequent Access (IA) storage class. For a file system without a LifecycleConfiguration object, the call returns an empty array in the response. This operation requires permissions for the elasticfilesystem:DescribeLifecycleConfiguration operation.

    Args:
        file_system_id(str): The ID of the file system whose LifecycleConfiguration object you want to retrieve (String).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.lifecycle_configuration.describe(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.lifecycle_configuration.describe file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_lifecycle_configuration",
        op_kwargs={"FileSystemId": file_system_id},
    )


async def put(hub, ctx, file_system_id: str, lifecycle_policies: List) -> Dict:
    r"""
    **Autogenerated function**

    Enables lifecycle management by creating a new LifecycleConfiguration object. A LifecycleConfiguration object defines when files in an Amazon EFS file system are automatically transitioned to the lower-cost EFS Infrequent Access (IA) storage class. A LifecycleConfiguration applies to all files in a file system. Each Amazon EFS file system supports one lifecycle configuration, which applies to all files in the file system. If a LifecycleConfiguration object already exists for the specified file system, a PutLifecycleConfiguration call modifies the existing configuration. A PutLifecycleConfiguration call with an empty LifecyclePolicies array in the request body deletes any existing LifecycleConfiguration and disables lifecycle management. In the request, specify the following:    The ID for the file system for which you are enabling, disabling, or modifying lifecycle management.   A LifecyclePolicies array of LifecyclePolicy objects that define when files are moved to the IA storage class. The array can contain only one LifecyclePolicy item.   This operation requires permissions for the elasticfilesystem:PutLifecycleConfiguration operation. To apply a LifecycleConfiguration object to an encrypted file system, you need the same AWS Key Management Service (AWS KMS) permissions as when you created the encrypted file system.

    Args:
        file_system_id(str): The ID of the file system for which you are creating the LifecycleConfiguration object (String).
        lifecycle_policies(List): An array of LifecyclePolicy objects that define the file system's LifecycleConfiguration object. A LifecycleConfiguration object tells lifecycle management when to transition files from the Standard storage class to the Infrequent Access storage class.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.lifecycle_configuration.put(
                ctx, file_system_id=value, lifecycle_policies=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.lifecycle_configuration.put file_system_id=value, lifecycle_policies=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="put_lifecycle_configuration",
        op_kwargs={
            "FileSystemId": file_system_id,
            "LifecyclePolicies": lifecycle_policies,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    type_: str,
    actions: List,
    workflow_name: str = None,
    schedule: str = None,
    predicate: Dict = None,
    description: str = None,
    start_on_creation: bool = None,
    tags: Dict = None,
    event_batching_condition: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new trigger.

    Args:
        name(str): The name of the trigger.
        workflow_name(str, optional): The name of the workflow associated with the trigger. Defaults to None.
        type_(str): The type of the new trigger.
        schedule(str, optional): A cron expression used to specify the schedule (see Time-Based Schedules for Jobs and Crawlers. For example, to run something every day at 12:15 UTC, you would specify: cron(15 12 * * ? *). This field is required when the trigger type is SCHEDULED. Defaults to None.
        predicate(Dict, optional): A predicate to specify when the new trigger should fire. This field is required when the trigger type is CONDITIONAL. Defaults to None.
        actions(List): The actions initiated by this trigger when it fires.
        description(str, optional): A description of the new trigger. Defaults to None.
        start_on_creation(bool, optional): Set to true to start SCHEDULED and CONDITIONAL triggers when created. True is not supported for ON_DEMAND triggers. Defaults to None.
        tags(Dict, optional): The tags to use with this trigger. You may use tags to limit access to the trigger. For more information about tags in Glue, see Amazon Web Services Tags in Glue in the developer guide. . Defaults to None.
        event_batching_condition(Dict, optional): Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.create(ctx, name=value, type_=value, actions=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.create name=value, type_=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_trigger",
        op_kwargs={
            "Name": name,
            "WorkflowName": workflow_name,
            "Type": type_,
            "Schedule": schedule,
            "Predicate": predicate,
            "Actions": actions,
            "Description": description,
            "StartOnCreation": start_on_creation,
            "Tags": tags,
            "EventBatchingCondition": event_batching_condition,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified trigger. If the trigger is not found, no exception is thrown.

    Args:
        name(str): The name of the trigger to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="delete_trigger", op_kwargs={"Name": name}
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the definition of a trigger.

    Args:
        name(str): The name of the trigger to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="get_trigger", op_kwargs={"Name": name}
    )


async def get_all(
    hub,
    ctx,
    next_token: str = None,
    dependent_job_name: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all the triggers associated with a job.

    Args:
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.
        dependent_job_name(str, optional): The name of the job to retrieve triggers for. The trigger that can start this job is returned, and if there is no such trigger, all triggers are returned. Defaults to None.
        max_results(int, optional): The maximum size of the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_triggers",
        op_kwargs={
            "NextToken": next_token,
            "DependentJobName": dependent_job_name,
            "MaxResults": max_results,
        },
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    dependent_job_name: str = None,
    max_results: int = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the names of all trigger resources in this Amazon Web Services account, or the resources with the specified tag. This operation allows you to see which resources are available in your account, and their names. This operation takes the optional Tags field, which you can use as a filter on the response so that tagged resources can be retrieved as a group. If you choose to use tags filtering, only resources with the tag are retrieved.

    Args:
        next_token(str, optional): A continuation token, if this is a continuation request. Defaults to None.
        dependent_job_name(str, optional):  The name of the job for which to retrieve triggers. The trigger that can start this job is returned. If there is no such trigger, all triggers are returned. Defaults to None.
        max_results(int, optional): The maximum size of a list to return. Defaults to None.
        tags(Dict, optional): Specifies to return only these tagged resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_triggers",
        op_kwargs={
            "NextToken": next_token,
            "DependentJobName": dependent_job_name,
            "MaxResults": max_results,
            "Tags": tags,
        },
    )


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts an existing trigger. See Triggering Jobs for information about how different types of trigger are started.

    Args:
        name(str): The name of the trigger to start.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="start_trigger", op_kwargs={"Name": name}
    )


async def stop(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a specified trigger.

    Args:
        name(str): The name of the trigger to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.stop(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.stop name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="stop_trigger", op_kwargs={"Name": name}
    )


async def update(hub, ctx, name: str, trigger_update: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates a trigger definition.

    Args:
        name(str): The name of the trigger to update.
        trigger_update(Dict): The new values with which to update the trigger.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.trigger.update(ctx, name=value, trigger_update=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.trigger.update name=value, trigger_update=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_trigger",
        op_kwargs={"Name": name, "TriggerUpdate": trigger_update},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, repository_name: str, registry_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the lifecycle policy associated with the specified repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.lifecycle_policy.init.delete(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.lifecycle_policy.init.delete repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="delete_lifecycle_policy",
        op_kwargs={"registryId": registry_id, "repositoryName": repository_name},
    )


async def get(hub, ctx, repository_name: str, registry_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the lifecycle policy for the specified repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.lifecycle_policy.init.get(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.lifecycle_policy.init.get repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="get_lifecycle_policy",
        op_kwargs={"registryId": registry_id, "repositoryName": repository_name},
    )


async def put(
    hub, ctx, repository_name: str, lifecycle_policy_text: str, registry_id: str = None
) -> Dict:
    r"""
       **Autogenerated function**

       Creates or updates the lifecycle policy for the specified repository. For more information, see Lifecycle Policy Template.

       Args:
           registry_id(str, optional): The AWS account ID associated with the registry that contains the repository. If you do
    not specify a registry, the default registry is assumed. Defaults to None.
           repository_name(str): The name of the repository to receive the policy.
           lifecycle_policy_text(str): The JSON repository policy text to apply to the repository.

       Returns:
           Dict

       Examples:
           Call from code:

           .. code-block:: python

               await hub.exec.aws_auto.ecr.lifecycle_policy.init.put(
                   ctx, repository_name=value, lifecycle_policy_text=value
               )

           Call from CLI:

           .. code-block:: bash

               $ idem exec aws_auto.ecr.lifecycle_policy.init.put repository_name=value, lifecycle_policy_text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="put_lifecycle_policy",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "lifecyclePolicyText": lifecycle_policy_text,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are deleted as well.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to which to add tags. Currently, the supported resources are Amazon ECS capacity providers, tasks, services, task definitions, clusters, and container instances.
        tags(List): The tags to add to the resource. A tag is an array of key-value pairs. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes specified tags from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource from which to delete tags. Currently, the supported resources are Amazon ECS capacity providers, tasks, services, task definitions, clusters, and container instances.
        tag_keys(List): The keys of the tags to be removed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, organization_id: str, name: str, display_name: str, password: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a user who can be used in Amazon WorkMail by calling the RegisterToWorkMail operation.

    Args:
        organization_id(str): The identifier of the organization for which the user is created.
        name(str): The name for the new user. WorkMail directory user names have a maximum length of 64. All others have a maximum length of 20.
        display_name(str): The display name for the new user.
        password(str): The password for the new user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.user.create(
                ctx, organization_id=value, name=value, display_name=value, password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.user.create organization_id=value, name=value, display_name=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="create_user",
        op_kwargs={
            "OrganizationId": organization_id,
            "Name": name,
            "DisplayName": display_name,
            "Password": password,
        },
    )


async def delete(hub, ctx, organization_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a user from Amazon WorkMail and all subsequent systems. Before you can delete a user, the user state must be DISABLED. Use the DescribeUser action to confirm the user state. Deleting a user is permanent and cannot be undone. WorkMail archives user mailboxes for 30 days before they are permanently removed.

    Args:
        organization_id(str): The organization that contains the user to be deleted.
        user_id(str): The identifier of the user to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.user.delete(ctx, organization_id=value, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.user.delete organization_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_user",
        op_kwargs={"OrganizationId": organization_id, "UserId": user_id},
    )


async def describe(hub, ctx, organization_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information regarding the user.

    Args:
        organization_id(str): The identifier for the organization under which the user exists.
        user_id(str): The identifier for the user to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.user.describe(
                ctx, organization_id=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.user.describe organization_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="describe_user",
        op_kwargs={"OrganizationId": organization_id, "UserId": user_id},
    )


async def list_all(
    hub, ctx, organization_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns summaries of the organization's users.

    Args:
        organization_id(str): The identifier for the organization under which the users exist.
        next_token(str, optional): The token to use to retrieve the next page of results. The first call does not contain any tokens. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.user.list_all(ctx, organization_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.user.list_all organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_users",
        op_kwargs={
            "OrganizationId": organization_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    device_id: str,
    tracker_name: str,
    end_time_exclusive: str = None,
    next_token: str = None,
    start_time_inclusive: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the device position history from a tracker resource within a specified range of time.  Device positions are deleted after 30 days.

    Args:
        device_id(str): The device whose position history you want to retrieve.
        end_time_exclusive(str, optional): Specify the end time for the position history in  ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. By default, the value will be the time that the request is made. Requirement:   The time specified for EndTimeExclusive must be after the time for StartTimeInclusive.  . Defaults to None.
        next_token(str, optional): The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.  Default value: null . Defaults to None.
        start_time_inclusive(str, optional): Specify the start time for the position history in  ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. By default, the value will be 24 hours prior to the time that the request is made. Requirement:   The time specified for StartTimeInclusive must be before EndTimeExclusive.  . Defaults to None.
        tracker_name(str): The tracker resource receiving the request for the device position history.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.device_position.history.get(
                ctx, device_id=value, tracker_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.device_position.history.get device_id=value, tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="get_device_position_history",
        op_kwargs={
            "DeviceId": device_id,
            "EndTimeExclusive": end_time_exclusive,
            "NextToken": next_token,
            "StartTimeInclusive": start_time_inclusive,
            "TrackerName": tracker_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, product_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists supported phone number countries.

    Args:
        product_type(str): The phone number product type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.supported_phone_number_country.list_all(
                ctx, product_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.supported_phone_number_country.list_all product_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_supported_phone_number_countries",
        op_kwargs={"ProductType": product_type},
    )
